@@ -57,14 +57,33 @@ class Config(object):
     # Urls
     zenodo_sandbox_base_url='http://sandbox.zenodo.org'
     zenodo_real_base_url='https://zenodo.org'
-    
+
     ### ---------------------------------------
     ### -------------SMART CITIZEN-------------
     ### ---------------------------------------
     # # Urls
     # sensor_names_url_21='https://raw.githubusercontent.com/fablabbcn/smartcitizen-kit-21/master/lib/Sensors/Sensors.h'
     # sensor_names_url_20='https://raw.githubusercontent.com/fablabbcn/smartcitizen-kit-20/master/lib/Sensors/Sensors.h'
-    
+    calibrations_urls = [
+        'https://raw.githubusercontent.com/fablabbcn/smartcitizen-data/master/calibrations/calibrations.json'
+    ]
+
+    blueprints_urls = [
+        'https://raw.githubusercontent.com/fablabbcn/smartcitizen-data/master/blueprints/sck_21.json',
+        'https://raw.githubusercontent.com/fablabbcn/smartcitizen-data/master/blueprints/base.json',
+        'https://raw.githubusercontent.com/fablabbcn/smartcitizen-data/master/blueprints/csic_station.json',
+        'https://raw.githubusercontent.com/fablabbcn/smartcitizen-data/master/blueprints/muv_station.json',
+        # 'https://raw.githubusercontent.com/fablabbcn/smartcitizen-data/master/blueprints/parrot_soil.json',
+        'https://raw.githubusercontent.com/fablabbcn/smartcitizen-data/master/blueprints/sc_20_station_iscape.json',
+        'https://raw.githubusercontent.com/fablabbcn/smartcitizen-data/master/blueprints/sc_21_station_iscape.json',
+        'https://raw.githubusercontent.com/fablabbcn/smartcitizen-data/master/blueprints/sc_21_station_module.json',
+        'https://raw.githubusercontent.com/fablabbcn/smartcitizen-data/master/blueprints/sck.json',
+        'https://raw.githubusercontent.com/fablabbcn/smartcitizen-data/master/blueprints/sck_15.json',
+        'https://raw.githubusercontent.com/fablabbcn/smartcitizen-data/master/blueprints/sck_20.json',
+        'https://raw.githubusercontent.com/fablabbcn/smartcitizen-data/master/blueprints/sck_21.json',
+        'https://raw.githubusercontent.com/fablabbcn/smartcitizen-data/master/blueprints/sck_21_gps.json'
+    ]
+
     # Convertion table from API SC to Pandas
     # https://stackoverflow.com/questions/35339139/where-is-the-documentation-on-pandas-freq-tags
     # https://developer.smartcitizen.me/#get-historical-readings
@@ -85,6 +104,16 @@ class Config(object):
     _baseline_deltas = arange(30, 45, 5)
     # Lambdas for baseline ALS algorithm
     _baseline_als_lambdas = [1e5]
+
+    # TODO - DEFINE IF THIS IS NECESSARY
+    _platform_sensor_ids = {
+        'CO': None,
+        'NO2': None,
+        'H2S': None,
+        'NO': None,
+        'O3': None,
+        'SO2': None
+    }
     
     ### ---------------------------------------
     ### -------------METRICS DATA--------------
@@ -105,7 +134,93 @@ class Config(object):
                         'NO2': 8, 
                         'O3': 40
                     }
-    
+
+    # Alphasense data
+    _as_sensor_codes = {
+                        '132': 'ASA4_CO',
+                        '133': 'ASA4_H2S',
+                        '130': 'ASA4_NO',
+                        '212': 'ASA4_NO2',
+                        '214': 'ASA4_OX',
+                        '134': 'ASA4_SO2',
+                        '162': 'ASB4_CO',
+                        '133': 'ASB4_H2S',#
+                        '130': 'ASB4_NO', #
+                        '202': 'ASB4_NO2',
+                        '204': 'ASB4_OX',
+                        '164': 'ASB4_SO2'
+    }
+
+    # From Tables 2 and 3 of AAN 803-04
+    _as_t_comp = [-30, -20, -10, 0, 10, 20, 30, 40, 50]
+
+    _as_sensor_algs = {
+                        'ASA4_CO':  
+                                    {
+                                        1: ['n_t',      [1.0, 1.0, 1.0, 1.0, -0.2, -0.9, -1.5, -1.5, -1.5]],
+                                        4: ['kpp_t',    [13, 12, 16, 11, 4, 0, -15, -18, -36]],
+                                    },
+
+                        'ASA4_H2S': 
+                                    {
+                                        2: ['k_t',      [-1.5, -1.5, -1.5, -0.5, 0.5, 1.0, 0.8, 0.5, 0.3]],
+                                        1: ['n_t',      [3.0, 3.0, 3.0, 1.0, -1.0, -2.0, -1.5, -1.0, -0.5]]                                        
+                                    },
+
+                        'ASA4_NO': 
+                                    {
+                                        3: ['kp_t',     [0.7, 0.7, 0.7, 0.7, 0.8, 1.0, 1.2, 1.4, 1.6]],
+                                        4: ['kpp_t',    [-25, -25, -25, -25, -16, 0, 56, 200, 615]]                                        
+                                    },
+
+                        'ASA4_NO2': 
+                                    {
+                                        1: ['n_t',      [0.8, 0.8, 1.0, 1.2, 1.6, 1.8, 1.9, 2.5, 3.6]],
+                                        3: ['kp_t',     [0.2, 0.2, 0.2, 0.2, 0.7, 1.0, 1.3, 2.1, 3.5]]
+                                    },
+
+                        'ASA4_OX':  
+                                    {
+                                        3: ['kp_t',     [0.1, 0.1, 0.2, 0.3, 0.7, 1.0, 1.7, 3.0, 4.0]],
+                                        1: ['n_t',      [1.0, 1.2, 1.2, 1.6, 1.7, 2.0, 2.1, 3.4, 4.6]]
+                                    },
+                        'ASA4_SO2': 
+                                    {
+                                        4: ['kpp_t',    [0, 0, 0, 0, 0, 0, 5, 25, 45]],
+                                        1: ['n_t',      [1.3, 1.3, 1.3, 1.2, 0.9, 0.4, 0.4, 0.4, 0.4]]
+                                    },
+                        'ASB4_CO':
+                                    {
+                                        1: ['n_t',      [0.7, 0.7, 0.7, 0.7, 1.0, 3.0, 3.5, 4.0, 4.5]],
+                                        2: ['k_t',      [0.2, 0.2, 0.2, 0.2, 0.3, 1.0, 1.2, 1.3, 1.5]]
+                                    },                        
+                        'ASB4_H2S': 
+                                    {
+                                        1: ['n_t',      [-0.6, -0.6, 0.1, 0.8, -0.7, -2.5, -2.5, -2.2, -1.8]],
+                                        2: ['k_t',      [0.2, 0.2, 0.0, -0.3, 0.3, 1.0, 1.0, 0.9, 0.7]]
+                                    },     
+                        'ASB4_NO':  
+                                    {
+                                        2: ['k_t',      [1.8, 1.8, 1.4, 1.1, 1.1, 1.0, 0.9, 0.9, 0.8]],
+                                        3: ['kp_t',     [0.8, 0.8, 0.8, 0.8, 0.9, 1.0, 1.1, 1.2, 1.3]]                                        
+                                    },
+                        'ASB4_NO2': 
+                                    {
+                                        1: ['n_t',      [1.3, 1.3, 1.3, 1.3, 1.0, 0.6, 0.4, 0.2, -1.5]],
+                                        3: ['kp_t',     [1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 0.4, -0.1, -4.0]]
+                                    },                           
+                        'ASB4_OX':
+                                    {
+                                        1: ['n_t',      [0.9, 0.9, 1.0, 1.3, 1.5, 1.7, 2.0, 2.5, 3.7]],
+                                        3: ['kp_t',     [0.5, 0.5, 0.5, 0.6, 0.6, 1.0, 2.8, 5.0, 5.3]]
+                                    },                         
+                        'ASB4_SO2':
+                                    {
+                                        4: ['kpp_t',    [-4, -4, -4, -4, -4, 0, 20, 140, 450]],
+                                        1: ['n_t',      [1.6, 1.6, 1.6, 1.6, 1.6, 1.6, 1.9, 3.0, 5.8]]
+                                    },                        
+    }
+
     # This look-up table is comprised of channels you want always want to have with the same units and that might come from different sources
     # i.e. pollutant data in various units (ppm or ug/m3) from different analysers
     # The table should be used as follows:
@@ -120,7 +235,7 @@ class Config(object):
                     "PM_(\d|[A,B]_\d)": "ug/m3",
                     "CO(\D|$)": "ppm",
                     "NOISE_A": "dBA",
-                    "NO": "ppb",
+                    "NO\Z": "ppb",
                     "NO2": "ppb",
                     "NOX": "ppb",
                     "O3": "ppb",
@@ -231,7 +346,7 @@ class Config(object):
                             'legend': True,
                             'style': _plot_style,
                             'kind': 'reg',
-                            'sharex': True,
+                            'sharex': False,
                             'sharey': False,
                             'nrows': 1
                             },
@@ -364,6 +479,16 @@ class Config(object):
                             }
                     }
 
+    _discvars = ['readings',
+                 'api_device',
+                 'options',
+                 'loaded',
+                 'hw_id',
+                 'latest_postprocessing',
+                 'blueprint_loaded_from_url',
+                 'hw_loaded_from_url',
+                 'hw_url']
+
     def __init__(self):
         self._env_file = False
         self.paths = get_paths()
@@ -385,13 +510,13 @@ class Config(object):
             return val
 
     def __iter__(self):
-        return (i for i in dir(self))            
+        return (i for i in dir(self))
     
     def get_meta_data(self):
-        """ Get meta data from blueprints and calibrations """
+        """ Get meta data from blueprints and _calibrations """
         # Blueprints and calibrations
-        blueprints = load_blueprints(self.paths)
-        calibrations = load_calibrations(self.paths)
+        blueprints = load_blueprints(self.blueprints_urls)
+        calibrations = load_calibrations(self.calibrations_urls)
 
         if calibrations is not None: self.calibrations = calibrations
         if blueprints is not None: self.blueprints = blueprints
