@@ -1,3 +1,8 @@
+'''
+Smartcitizen Kit python library.
+This library is meant to be run inside the firmware repository folder.
+'''
+
 import os
 import subprocess
 try:
@@ -21,10 +26,7 @@ except ModuleNotFoundError:
         print ('Cannot import serialdevice')
         traceback.print_exc()
         pass
-'''
-Smartcitizen Kit python library.
-This library is meant to be run inside the firmware repository folder.
-'''
+
 
 class sck(serialdevice):
 
@@ -90,6 +92,8 @@ class sck(serialdevice):
     wifi_ssid = ''
     wifi_pass = ''
 
+    blueprint_id = 26
+
     def begin(self, get_sensors = False):
         if self.set_serial():
             if get_sensors:
@@ -430,7 +434,7 @@ class sck(serialdevice):
         device['device_token'] = binascii.b2a_hex(os.urandom(3)).decode('utf-8')
         self.token = device['device_token']
         device['description'] = ''
-        device['kit_id'] = 26
+        device['kit_id'] = self.blueprint_id
         device['latitude'] = 41.396867
         device['longitude'] = 2.194351
         device['exposure'] = 'indoor'
